==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/GXModules/Swix/PostfinanceCheckout/Shop/TextPhrases/german/swixpostfinancecheckout_postfinancecard.lang.inc.php <==
<?php
/*--------------------------------------------------------------------------------------------------
    swixpostfinancecheckout_postfinancecard.php 2021-07-13
    swisswebXperts GmbH
    https://www.swisswebxperts.ch
    Copyright (c) 2021 swisswebXperts GmbH
    Released under the GNU General Public License (Version 2)
    [http://www.gnu.org/licenses/gpl-2.0.html]
    --------------------------------------------------------------------------------------------------
 */

$t_language_text_section_content_array = [
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_TEXT_TITLE'                  => 'Postfinance Card',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_TEXT_DESC'                   => '',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_STATUS_TITLE'                => 'Zahlungsmodul aktivieren?',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_STATUS_DESC'                 => 'Möchten Sie Zahlungen mit Postfinance Card akzeptieren?',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_SORT_ORDER_TITLE'            => 'Anzeigereihenfolge',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_SORT_ORDER_DESC'             => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ALLOWED_TITLE'               => 'Erlaubte Zonen',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ALLOWED_DESC'                => 'Geben Sie einzeln die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ZONE_TITLE'                  => 'Zahlungszone',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ZONE_DESC'                   => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ORDER_STATUS_ID_TITLE'       => 'Bestellstatus festlegen',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ORDER_STATUS_ID_DESC'        => 'Bestellungen, welche mit diesem Modul gemacht werden, auf diesen Status setzen.',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ERROR_ORDER_STATUS_ID_TITLE' => 'Bestellstatus bei Abbruch festlegen',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ERROR_ORDER_STATUS_ID_DESC'  => 'Abgebrochene oder abgelehnte Bestellungen auf diesen Status setzen.',
];

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/GXModules/Swix/PostfinanceCheckout/Shop/TextPhrases/german/swixpostfinancecheckout_postfinancecard.lang.inc.php <==
<?php
/*--------------------------------------------------------------------------------------------------
    swixpostfinancecheckout_postfinancecard.php 2021-07-13
    swisswebXperts GmbH
    https://www.swisswebxperts.ch
    Copyright (c) 2021 swisswebXperts GmbH
    Released under the GNU General Public License (Version 2)
    [http://www.gnu.org/licenses/gpl-2.0.html]
    --------------------------------------------------------------------------------------------------
 */

$t_language_text_section_content_array = [
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_TEXT_TITLE'                  => 'Postfinance Card',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_TEXT_DESC'                   => '',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_STATUS_TITLE'                => 'Zahlungsmodul aktivieren?',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_STATUS_DESC'                 => 'Möchten Sie Zahlungen mit Postfinance Card akzeptieren?',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_SORT_ORDER_TITLE'            => 'Anzeigereihenfolge',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_SORT_ORDER_DESC'             => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ALLOWED_TITLE'               => 'Erlaubte Zonen',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ALLOWED_DESC'                => 'Geben Sie einzeln die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ZONE_TITLE'                  => 'Zahlungszone',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ZONE_DESC'                   => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ORDER_STATUS_ID_TITLE'       => 'Bestellstatus festlegen',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ORDER_STATUS_ID_DESC'        => 'Bestellungen, welche mit diesem Modul gemacht werden, auf diesen Status setzen.',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ERROR_ORDER_STATUS_ID_TITLE' => 'Bestellstatus bei Abbruch festlegen',
    'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_ERROR_ORDER_STATUS_ID_DESC'  => 'Abgebrochene oder abgelehnte Bestellungen auf diesen Status setzen.',
	'MODULE_PAYMENT_SWIXPOSTFINANCECHECKOUT_POSTFINANCECARD_TEXT_INFO' 					 => 'Einfach und schnell bezahlen direkt mit Ihrer PostFinance Card.',
];
